@@ -1,44 +1,32 @@
 package Yukki;
-$Yukki::VERSION = '0.991_007'; # TRIAL
-$Yukki::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
+BEGIN {
+  $Yukki::VERSION = '0.110830';
+}
+use 5.12.1;
+use Moose;
 
-use Class::Load;
+use Yukki::Types qw( AccessLevel );
 
-use Yukki::Settings;
-use Yukki::TextUtil qw( load_file );
-use Yukki::Types qw( AccessLevel YukkiSettings );
-use Yukki::Error qw( http_throw );
+use MooseX::Params::Validate;
+use MooseX::Types::Path::Class;
+use Path::Class;
+use YAML qw( LoadFile );
 
-use Crypt::SaltedHash;
-use List::Util qw( any );
-use Type::Params qw( validate );
-use Type::Utils;
-use Types::Standard qw( Dict HashRef Str Maybe slurpy Optional );
-use Path::Tiny;
-use Types::Path::Tiny qw( Path );
-use Try::Tiny;
-
-use namespace::clean;
-
-# ABSTRACT: Yet Uh-nother wiki - a git-based wiki with workgroups
+# ABSTRACT: Yet Uh-nother wiki
 
 
 has config_file => (
     is          => 'ro',
-    isa         => Path,
+    isa         => 'Path::Class::File',
     required    => 1,
     coerce      => 1,
-    lazy        => 1,
-    builder     => '_build_config_file',
+    lazy_build  => 1,
 );
 
 sub _build_config_file {
     my $self = shift;
 
-    my $cwd_conf = path('.', 'etc', 'yukki.conf');
+    my $cwd_conf = file(dir(), 'etc', 'yukki.conf');
     if (not $ENV{YUKKI_CONFIG} and -f "$cwd_conf") {
         return $cwd_conf;
     }
@@ -55,16 +43,14 @@ sub _build_config_file {
 
 has settings => (
     is          => 'ro',
-    isa         => YukkiSettings,
+    isa         => 'HashRef',
     required    => 1,
-    coerce      => 1,
-    lazy        => 1,
-    builder     => '_build_settings',
+    lazy_build  => 1,
 );
 
 sub _build_settings {
     my $self = shift;
-    load_file($self->config_file)
+    LoadFile(''.$self->config_file);
 }
 
 
@@ -77,7 +63,7 @@ sub controller { ... }
 sub model {
     my ($self, $name, $params) = @_;
     my $class_name = join '::', 'Yukki::Model', $name;
-    Class::Load::load_class($class_name);
+    Class::MOP::load_class($class_name);
     return $class_name->new(app => $self, %{ $params // {} });
 }
 
@@ -85,23 +71,17 @@ sub model {
 sub _locate {
     my ($self, $type, $base, @extra_path) = @_;
 
-    my $base_path = $self->settings->$base;
-    my $root_path;
+    my $path_class = $type eq 'file' ? 'Path::Class::File'
+                   : $type eq 'dir'  ? 'Path::Class::Dir'
+                   : Yukki::Error->throw("unkonwn location type $type");
 
+    my $base_path = $self->settings->{$base};
     if ($base_path !~ m{^/}) {
-        $root_path = path($self->settings->root, $base_path);
+        return $path_class->new($self->settings->{root}, $base_path, @extra_path);
     }
     else {
-        $root_path = path($base_path);
+        return $path_class->new($base_path, @extra_path);
     }
-
-    my $located_path = $root_path->child(@extra_path);
-
-    # Small safety mechanism
-    die "attempted to lookup an illegal $base path: ", join('/', @extra_path)
-        unless $root_path->subsumes($located_path);
-
-    return $located_path;
 }
 
 sub locate {
@@ -117,42 +97,25 @@ sub locate_dir {
 
 
 sub check_access {
-    my ($self, $opt)
-        = validate(\@_, class_type(__PACKAGE__),
-            slurpy Dict[
-                user       => Maybe[class_type('Yukki::User')],
-                special    => Optional[Str],
-                repository => Optional[Str],
-                needs      => AccessLevel,
-            ]
-        );
-    my ($user, $repository, $special, $needs)
-        = @{$opt}{qw( user repository special needs )};
+    my ($self, $user, $repository, $needs) = validated_list(\@_,
+        user       => { isa => 'Undef|HashRef', optional => 1 },
+        repository => { isa => 'Str' },
+        needs      => { isa => AccessLevel },
+    );
 
-    $repository //= '-';
-    $special //= '-';
+    my $config = $self->settings->{repositories}{$repository}
+              // {};
 
-    # Always grant none
-    return 1 if $needs eq 'none';
-
-    my $config;
-    $config   = try {
-        $self->model('Root')->repository($repository)->repository_settings;
-    };
-    $config //= $self->settings->special_privileges->{$special};
-
-    return '' unless $config;
-
-    my $read_groups  = $config->read_groups;
-    my $write_groups = $config->write_groups;
+    my $read_groups  = $config->{read_groups}  // 'NONE';
+    my $write_groups = $config->{write_groups} // 'NONE';
 
     my %access_level = (none => 0, read => 1, write => 2);
     my $has_access = sub {
         $access_level{$_[0] // 'none'} >= $access_level{$needs}
     };
 
-    # Deal with anonymous users first.
-    return 1 if $has_access->($config->anonymous_access_level);
+    # Deal with anonymous users first. 
+    return 1 if $has_access->($config->{anonymous_access_level});
     return '' unless $user;
 
     # Only logged users considered here forward.
@@ -161,52 +124,40 @@ sub check_access {
     for my $level (qw( read write )) {
         if ($has_access->($level)) {
 
-            my $groups = "${level}_groups";
+            return 1 if $config->{"${level}_groups"} ~~ 'ANY';
 
-            return 1 if $config->$groups eq 'ANY';
-
-            if (ref $config->$groups eq 'ARRAY') {
-                my @level_groups = @{ $config->$groups };
+            if (ref $config->{"${level}_groups"} eq 'ARRAY') {
+                my @level_groups = @{ $config->{"${level}_groups"} };
 
                 for my $level_group (@level_groups) {
-                    return 1 if any { $_ eq $level_group } @user_groups;
+                    return 1 if $level_group ~~ @user_groups;
                 }
             }
-            elsif ($config->$groups ne 'NONE') {
-                warn "weird value ", $config->$groups,
-                    " in $groups config for $repository settings";
+            else {
+                warn "weird value in ${level}_groups config for ",
+                     "$repository settings";
             }
         }
-    }
+    } 
 
     return '';
 }
 
-
-sub hasher {
-    my $self = shift;
-
-    return Crypt::SaltedHash->new(algorithm => $self->settings->digest);
-}
-
 with qw( Yukki::Role::App );
 
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Yukki - Yet Uh-nother wiki - a git-based wiki with workgroups
+Yukki - Yet Uh-nother wiki
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -262,19 +213,19 @@ the instance constructor.
 The first argument is the name of the configuration directive naming the path.
 It may be followed by one or more path components to be tacked on to the end.
 
-Returns a L<Path::Tiny> for the file.
+Returns a L<Path::Class::File> for the file.
 
 =head2 locate_dir
 
   my $dir = $app->locate_dir('repository_path', 'main.git');
 
-The arguments are identical to L</locate>, but returns a L<Path::Tiny> for
+The arguments are identical to L</locate>, but returns a L<Path::Class::Dir> for
 the given file.
 
 =head2 check_access
 
   my $access_is_ok = $app->check_access({
-      user       => $user,
+      user       => $user, 
       repository => 'main',
       needs      => 'read',
   });
@@ -286,10 +237,6 @@ level the user needs. It must be an L<Yukki::Types/AccessLevel>.
 
 The method returns a true value if access should be granted or false otherwise.
 
-=head2 hasher
-
-Returns a message digest object that can be used to create a cryptographic hash.
-
 =head1 WHY?
 
 I wanted a Perl-based, MultiMarkdown-supporting wiki that I could take sermon notes and personal study notes for church and Bible study and such. However, I'm offline at church, so I want to do this from my laptop and sync it up to the master wiki when I get home. That's it.
@@ -302,9 +249,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
