@@ -1,20 +1,15 @@
 package Yukki::Model;
-$Yukki::Model::VERSION = '0.991_007'; # TRIAL
-$Yukki::Model::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Type::Utils;
-
-use namespace::clean;
+BEGIN {
+  $Yukki::Model::VERSION = '0.110830';
+}
+use Moose;
 
 # ABSTRACT: Base class for model objects
 
 
 has app => (
     is          => 'ro',
-    isa         => class_type('Yukki'),
+    isa         => 'Yukki',
     required    => 1,
     weak_ref    => 1,
     handles     => 'Yukki::Role::App',
@@ -23,18 +18,15 @@ has app => (
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Model - Base class for model objects
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -52,9 +44,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
