@@ -1,9 +1,8 @@
 package Yukki::Role::App;
-$Yukki::Role::App::VERSION = '0.991_007'; # TRIAL
-$Yukki::Role::App::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo::Role;
+BEGIN {
+  $Yukki::Role::App::VERSION = '0.110830';
+}
+use Moose::Role;
 
 requires qw(
     model
@@ -20,18 +19,15 @@ requires qw(
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Role::App - the role Yukki app-classes implement
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -76,8 +72,8 @@ installation.
 
 =head2 check_access
 
-  my $access_is_ok = $self->check_access({
-      user       => $user,
+  my $access_is_ok = $self->check_access({ 
+      user       => $user, 
       repository => $repository,
       needs      => $needs,
   });
@@ -95,9 +91,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
