@@ -1,43 +1,35 @@
 package Yukki::Web::Controller;
-$Yukki::Web::Controller::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Controller::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo::Role;
-
-use Type::Utils;
-
-use namespace::clean;
+BEGIN {
+  $Yukki::Web::Controller::VERSION = '0.110830';
+}
+use Moose;
 
 # ABSTRACT: Base class for Yukki::Web controllers
 
 
 has app => (
     is          => 'ro',
-    isa         => class_type('Yukki::Web'),
+    isa         => 'Yukki::Web',
     required    => 1,
     weak_ref    => 1,
     handles     => 'Yukki::Role::App',
 );
 
 
-requires 'fire';
+sub fire { die 'not implemented here' }
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Controller - Base class for Yukki::Web controllers
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -65,9 +57,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
