@@ -1,13 +1,11 @@
 package Yukki::Web::Controller::Redirect;
-$Yukki::Web::Controller::Redirect::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Controller::Redirect::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
+BEGIN {
+  $Yukki::Web::Controller::Redirect::VERSION = '0.110830';
+}
+use 5.12.1;
+use Moose;
 
-use Yukki::Error qw( http_throw );
-
-use namespace::clean;
+use HTTP::Throwable::Factory qw( http_throw );
 
 # ABSTRACT: Simple controller for handling internal redirects
 
@@ -17,29 +15,23 @@ sub fire {
 
     my $redirect = $ctx->request->path_parameters->{redirect};
 
-    http_throw("no redirect URL named") unless $redirect;
+    Yukki::Error->throw("no redirect URL named") unless $redirect;
 
-    http_throw("Go to $redirect.", {
-        status   => 'MovedPermanently',
-        location => $redirect,
-    });
+    http_throw('MovedPermanently', { location => $redirect });
 }
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Controller::Redirect - Simple controller for handling internal redirects
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -57,9 +49,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
