@@ -1,38 +1,32 @@
 package Yukki::Web::Request;
-$Yukki::Web::Request::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Request::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
+BEGIN {
+  $Yukki::Web::Request::VERSION = '0.110830';
+}
+use Moose;
 
 use Plack::Request;
-use Type::Utils;
-use Types::Standard qw( HashRef );
-
-use namespace::clean;
 
 # ABSTRACT: Yukki request descriptor
 
 
 has env => (
     is          => 'ro',
-    isa         => HashRef,
+    isa         => 'HashRef',
     required    => 1,
 );
 
 
 has request => (
     is          => 'ro',
-    isa         => class_type('Plack::Request'),
+    isa         => 'Plack::Request',
     required    => 1,
-    lazy        => 1,
-    builder     => '_build_request',
+    lazy_build  => 1,
     handles     => [ qw(
         address remote_host method protocol request_uri path_info path script_name scheme
         secure body input session session_options logger cookies query_parameters
         body_parameters parameters content raw_body uri base user headers uploads
         content_encoding content_length content_type header referer user_agent param
-        upload
+        upload 
     ) ],
 );
 
@@ -44,26 +38,24 @@ sub _build_request {
 
 has path_parameters => (
     is          => 'rw',
-    isa         => HashRef,
+    isa         => 'HashRef',
     required    => 1,
     default     => sub { +{} },
 );
 
 1;
 
+
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Request - Yukki request descriptor
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -83,7 +75,7 @@ This is the internal L<Plack::Request> object. Do not use. Use one of the method
   secure body input session session_options logger cookies query_parameters
   body_parameters parameters content raw_body uri base user headers uploads
   content_encoding content_length content_type header referer user_agent param
-  upload
+  upload 
 
 =head2 path_parameters
 
@@ -95,9 +87,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
