@@ -1,19 +1,17 @@
 package Yukki::Web::Router::Route;
-$Yukki::Web::Router::Route::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Router::Route::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
+BEGIN {
+  $Yukki::Web::Router::Route::VERSION = '0.110830';
+}
+use Moose;
 
 extends 'Path::Router::Route';
 
 use Yukki::Types qw( AccessLevel );
 use Yukki::Web::Router::Route::Match;
 
-use Types::Standard qw( ArrayRef HashRef Tuple );
-use List::Util qw( any );
-
-use namespace::clean;
+use MooseX::Types::Moose qw( ArrayRef HashRef );
+use MooseX::Types::Structured qw( Tuple );
+use List::MoreUtils qw( any );
 
 # ABSTRACT: Adds ACLs to routes
 
@@ -124,18 +122,15 @@ sub match {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Router::Route - Adds ACLs to routes
 
 =head1 VERSION
 
-version 0.991_007
+version 0.110830
 
 =head1 DESCRIPTION
 
@@ -189,9 +184,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
